Objects
=======

The :class:`pyvista.DataObject` class is a set of common methods and attributes
for all PyVista types. These objects have no spatial reference, but simply
hold data.

.. rubric:: Attributes

.. autoautosummary:: pyvista.DataObject
   :attributes:

.. rubric:: Methods

.. autoautosummary:: pyvista.DataObject
   :methods:

.. autoclass:: pyvista.DataObject
   :show-inheritance:
   :members:
   :undoc-members:


Table
-----

The table class is a non-spatially referenced data object that can be used on
VTK pipelines and holds arrays of data.

.. rubric:: Attributes

.. autoautosummary:: pyvista.Table
   :attributes:

.. rubric:: Methods

.. autoautosummary:: pyvista.Table
   :methods:

.. autoclass:: pyvista.Table
   :show-inheritance:
   :members:
   :undoc-members:
